package org.herac.tuxguitar.gui.help.doc;


import java.io.File;
import java.net.URL;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.swt.SWT;
import org.eclipse.swt.browser.Browser;
import org.eclipse.swt.browser.LocationAdapter;
import org.eclipse.swt.browser.LocationEvent;
import org.eclipse.swt.custom.SashForm;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseMoveListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeItem;
import org.herac.tuxguitar.gui.util.DialogUtils;
import org.herac.tuxguitar.gui.util.TGFileUtils;

public class DocDialog {	

	private static final String URL_NOT_FOUND = ("<html><body><h2 align=\"center\">URL Not Found!</h2></body></html>");
	
	private Shell dialog;
	private SashForm form;	
	private Browser browser;
	protected Tree tree;
	
	public void show(Shell shell) throws DocException{
		try{			
			this.dialog = DialogUtils.newDialog(shell,SWT.DIALOG_TRIM | SWT.RESIZE);
			this.dialog.setLayout(new FillLayout());		
			this.form = new SashForm(this.dialog,SWT.HORIZONTAL | SWT.SMOOTH) ;
			this.tree = new Tree(this.form, SWT.BORDER | SWT.SINGLE );
			this.browser = new Browser(this.form, SWT.BORDER);
			this.form.setWeights(new int[]{1,4});
			this.initTreeItems();
			this.initTreeListener();
			this.initBrowserListener();
			
			DialogUtils.openDialog(this.dialog,DialogUtils.OPEN_STYLE_CENTER);
		}catch (Throwable trowable) {
			throw new DocException(trowable);
		}
	}
	
	protected void showUrl(String url){		
		String parsedUrl = parseURL(url);
		if(parsedUrl != null){
			this.browser.setUrl(parsedUrl);
		}else{
			this.browser.setText(URL_NOT_FOUND);
		}
	}	
	
	protected void initBrowserListener(){
		this.browser.addLocationListener(new LocationAdapter() {
			public void changed(LocationEvent event) {
				findSelectedItem();
			}
		});
	}
	
	protected void initTreeListener(){
		this.tree.addSelectionListener(new SelectionAdapter() {	
			public void widgetSelected(SelectionEvent e) {
				TreeItem item = (TreeItem) e.item;
				Object data = item.getData();
				if(data instanceof DocItem && ((DocItem)data).getUrl() != null){
					showUrl(((DocItem)data).getUrl());
				}			
			}
		});
		this.tree.addMouseMoveListener(new MouseMoveListener() {		
			public void mouseMove(MouseEvent e) {
				TreeItem item = DocDialog.this.tree.getItem(new Point(e.x,e.y));
				if(item != null){
					DocDialog.this.tree.setCursor(DocDialog.this.tree.getDisplay().getSystemCursor(SWT.CURSOR_HAND));					
				}else{
					DocDialog.this.tree.setCursor(DocDialog.this.tree.getDisplay().getSystemCursor(SWT.CURSOR_ARROW));				
				}
			}		
		});
	}
	
	protected void initTreeItems(){
		File file = getContentFile();
		if(file != null && file.exists()){
			List items = new ArrayList();
			new DocItemReader().loadHelpItems(items,file);		
			Iterator it = items.iterator();
			while(it.hasNext()){
				DocItem item = (DocItem)it.next();
				initSubItems(item,rootItem(item));
			}
		}
	}

	protected void initSubItems(DocItem item,TreeItem parent){
		Iterator it = item.getChildren().iterator();
		while(it.hasNext()){
			DocItem child = (DocItem)it.next();			
			initSubItems(child,subItem(parent ,child));			
		}
	}
	
	protected TreeItem rootItem(DocItem item){
		TreeItem treeItem = new TreeItem(this.tree,SWT.NONE);
		treeItem.setText(item.getName());
		treeItem.setData(item);		
		return treeItem;
	}	
	
	protected TreeItem subItem(TreeItem parent,DocItem item){
		TreeItem treeItem = new TreeItem(parent,SWT.NONE);
		treeItem.setText(item.getName());
		treeItem.setData(item);		
		return treeItem;
	}
	
	protected void findSelectedItem(){
		try {
			String url = this.browser.getUrl();
			if(url != null && url.length() > 0){
				boolean selected = false;
				String browserPath = new URL(url).getFile();
				TreeItem[] selection = this.tree.getSelection();
				if(selection != null && selection.length > 0 && selection[0].getData() instanceof DocItem){
					DocItem item = (DocItem)selection[0].getData();
					if( item.getUrl() != null ){
						String path = parseURL( item.getUrl());
						if(path != null && browserPath.equals( path )){
							selected = true;
						}
					}
				}
				
				if(!selected){
					TreeItem item = findSelectedItem(this.tree.getItems(), browserPath);
					if(item != null){
						this.tree.setSelection(item);
					}
				}
			}
		}catch (Throwable trowable) {
			new DocException(trowable).printStackTrace();
		}
	}
	
	protected TreeItem findSelectedItem(TreeItem[] items, String browserPath){
		for( int i = 0 ; i < items.length; i ++ ){
			if(items[i].getData() instanceof DocItem){
				DocItem item = (DocItem)items[ i ].getData();	
				if( item.getUrl() != null ){
					String path = parseURL( item.getUrl());
					if(path != null && browserPath.equals( path )){
						return items[ i ];
					}
				}
				TreeItem child = findSelectedItem( items[ i ].getItems() , browserPath );
				if(child != null){
					return child;
				}
			}
		}
		return null;
	}
	
	public String parseURL(String url){
		File file = new File(TGFileUtils.PATH_HELP + url);
		return (file.exists()?file.getAbsolutePath():null);
	}	
	
	private File getContentFile(){		
		return new File(TGFileUtils.PATH_HELP + "contents.xml");		
	}
}