package org.herac.tuxguitar.gui.system.icons;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.swt.graphics.Image;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.system.config.TGConfigKeys;
import org.herac.tuxguitar.gui.util.TGFileUtils;
import org.herac.tuxguitar.song.models.TGDuration;

public class IconManager {
	private String theme;
	private List loaders;	
	private Image[] durations;
	private Image editUndo;
	private Image editRedo;	
	private Image editModeSelection;
	private Image editModeEdition;
	private Image editModeEditionNotNatural;
	private Image layoutPage;
	private Image layoutLinear;
	private Image layoutMultitrack;
	private Image layoutScore;
	private Image layoutCompact;
	private Image transport;
	private Image transportFirst1;
	private Image transportFirst2;
	private Image transportLast1;
	private Image transportLast2;
	private Image transportPrevious1;
	private Image transportPrevious2;
	private Image transportNext1;
	private Image transportNext2;
	private Image transportStop1;
	private Image transportStop2;
	private Image transportPlay1;
	private Image transportPlay2;
	private Image transportPause;
	private Image transportIconFirst1;
	private Image transportIconFirst2;
	private Image transportIconLast1;
	private Image transportIconLast2;
	private Image transportIconPrevious1;
	private Image transportIconPrevious2;
	private Image transportIconNext1;
	private Image transportIconNext2;
	private Image transportIconStop1;
	private Image transportIconStop2;
	private Image transportIconPlay1;
	private Image transportIconPlay2;
	private Image transportIconPause;
	private Image transportMetronome;
	private Image transportMode;	
	private Image markerList;
	private Image markerAdd;
	private Image markerRemove;
	private Image markerFirst;
	private Image markerLast;
	private Image markerPrevious;
	private Image markerNext;		
	private Image aboutDescription;
	private Image aboutLicense;
	private Image aboutAuthors;	
	private Image appIcon;
	private Image appSplash;	
	private Image optionMain;
	private Image optionStyle;
	private Image optionSound;
	private Image optionLanguage;
	private Image optionToolbars;
	private Image optionSkin;
	private Image trackAdd;
	private Image trackRemove;
	private Image paintableTempo;	
	private Image paintableGrace;
	private Image fretboard;
	private Image fretboardFirstFret;
	private Image fretboardFret;				
	private Image compositionTimeSignature;
	private Image compositionTempo;
	private Image compositionRepeatOpen;
	private Image compositionRepeatClose;
	private Image compositionRepeatAlternative;
	private Image songProperties;	
	private Image durationDotted;
	private Image durationDoubleDotted;
	private Image durationTupleto;	
	private Image fileNew;
	private Image fileOpen;
	private Image fileSave;
	private Image fileSaveAs;
	private Image filePrint;
	private Image filePrintPreview;	
	private Image chord;
	private Image noteTied;
	private Image mixer;	
	private Image dynamicPPP;	
	private Image dynamicPP;		
	private Image dynamicP;		
	private Image dynamicMP;		
	private Image dynamicMF;		
	private Image dynamicF;		
	private Image dynamicFF;		
	private Image dynamicFFF;			
	private Image effectDead;
	private Image effectGhost;
	private Image effectAccentuated;
	private Image effectHeavyAccentuated;
	private Image effectHarmonic;
	private Image effectGrace;
	private Image effectBend;
	private Image effectTremoloBar;
	private Image effectSlide;
	private Image effectHammer;
	private Image effectVibrato;
	private Image effectTrill;
	private Image effectTremoloPicking;
	private Image effectPalmMute;	
	private Image effectStaccato;
	private Image effectTapping;
	private Image effectSlapping;
	private Image effectPopping;
	private Image effectFadeIn;	
	private Image browserNew;
	private Image browserFile;
	private Image browserFolder;
	private Image browserRoot;
	private Image browserBack;
	private Image browserRefresh;
	private Image settings;
	
	public IconManager(){
		this.loaders = new ArrayList();
		this.loadIcons();
	}
	
	public void addLoader(IconLoader loader){
		this.loaders.add(loader);
	}

	public void removeLoader(IconLoader loader){
		this.loaders.remove(loader);
	}
	
	private void fireChanges(){
		Iterator it = this.loaders.iterator();
		while(it.hasNext()){
			IconLoader loader = (IconLoader)it.next();
			loader.loadIcons();
		}
	}
	
	public void reloadIcons(){
		this.disposeIcons();
		this.loadIcons();
		this.fireChanges();
	}
	
	public void loadIcons(){ 					
		this.theme = TuxGuitar.instance().getConfig().getStringConfigValue(TGConfigKeys.SKIN);
		this.durations = new Image[]{
			TGFileUtils.loadImage("1.png"),
			TGFileUtils.loadImage("2.png"),
			TGFileUtils.loadImage("4.png"),
			TGFileUtils.loadImage("8.png"),
			TGFileUtils.loadImage("16.png"),
			TGFileUtils.loadImage("32.png"),
			TGFileUtils.loadImage("64.png")
		};
		this.paintableTempo = TGFileUtils.loadImage("tempo.png");
		this.paintableGrace = TGFileUtils.loadImage("grace.png");
		this.layoutPage = TGFileUtils.loadImage("layout_page.png");
		this.layoutLinear = TGFileUtils.loadImage("layout_linear.png");
		this.layoutMultitrack = TGFileUtils.loadImage("layout_multitrack.png");
		this.layoutScore = TGFileUtils.loadImage("layout_score.png");
		this.layoutCompact = TGFileUtils.loadImage("layout_compact.png");
		this.fileNew = TGFileUtils.loadImage("new.png");
		this.fileOpen = TGFileUtils.loadImage("open.png");
		this.fileSave = TGFileUtils.loadImage("save.png");
		this.fileSaveAs = TGFileUtils.loadImage("save-as.png");
		this.filePrint = TGFileUtils.loadImage("print.png");
		this.filePrintPreview = TGFileUtils.loadImage("print-preview.png");				
		this.editUndo = TGFileUtils.loadImage("undo.png");
		this.editRedo = TGFileUtils.loadImage("redo.png");	
		this.editModeSelection = TGFileUtils.loadImage("edit_mode_selection.png");
		this.editModeEdition = TGFileUtils.loadImage("edit_mode_edition.png");
		this.editModeEditionNotNatural = TGFileUtils.loadImage("edit_mode_edition_no_natural.png");				
		this.appIcon = TGFileUtils.loadImage("icon.png");
		this.appSplash = TGFileUtils.loadImage("splash.png");		
		this.aboutDescription = TGFileUtils.loadImage("about_description.png");
		this.aboutLicense = TGFileUtils.loadImage("about_license.png");
		this.aboutAuthors = TGFileUtils.loadImage("about_authors.png");
		this.optionMain = TGFileUtils.loadImage("option_view.png");
		this.optionStyle = TGFileUtils.loadImage("option_style.png");
		this.optionSound = TGFileUtils.loadImage("option_sound.png");
		this.optionSkin = TGFileUtils.loadImage("option_skin.png");
		this.optionLanguage= TGFileUtils.loadImage("option_language.png");
		this.optionToolbars = TGFileUtils.loadImage("option_toolbars.png");				
		this.compositionTimeSignature = TGFileUtils.loadImage("timesignature.png");
		this.compositionTempo = TGFileUtils.loadImage("tempoicon.png");
		this.compositionRepeatOpen = TGFileUtils.loadImage("openrepeat.png");
		this.compositionRepeatClose = TGFileUtils.loadImage("closerepeat.png");
		this.compositionRepeatAlternative = TGFileUtils.loadImage("repeat_alternative.png");
		this.songProperties = TGFileUtils.loadImage("song_properties.png");			
		this.trackAdd = TGFileUtils.loadImage("track_add.png");
		this.trackRemove = TGFileUtils.loadImage("track_remove.png");				
		this.durationDotted = TGFileUtils.loadImage("dotted.png");
		this.durationDoubleDotted = TGFileUtils.loadImage("doubledotted.png");
		this.durationTupleto = TGFileUtils.loadImage("tupleto.png");					
		this.fretboard = TGFileUtils.loadImage("fretboard.png");
		this.fretboardFirstFret = TGFileUtils.loadImage("firstfret.png");
		this.fretboardFret = TGFileUtils.loadImage("fret.png");						
		this.chord = TGFileUtils.loadImage("chord.png");
		this.noteTied = TGFileUtils.loadImage("tiednote.png");				
		this.transport = TGFileUtils.loadImage("transport.png");
		this.transportFirst1 = TGFileUtils.loadImage("transport_first_1.png");
		this.transportFirst2 = TGFileUtils.loadImage("transport_first_2.png");
		this.transportLast1 = TGFileUtils.loadImage("transport_last_1.png");
		this.transportLast2 = TGFileUtils.loadImage("transport_last_2.png");
		this.transportPrevious1 = TGFileUtils.loadImage("transport_previous_1.png");
		this.transportPrevious2 = TGFileUtils.loadImage("transport_previous_2.png");
		this.transportNext1 = TGFileUtils.loadImage("transport_next_1.png");
		this.transportNext2 = TGFileUtils.loadImage("transport_next_2.png");
		this.transportStop1 = TGFileUtils.loadImage("transport_stop_1.png");
		this.transportStop2 = TGFileUtils.loadImage("transport_stop_2.png");
		this.transportPlay1 = TGFileUtils.loadImage("transport_play_1.png");
		this.transportPlay2 = TGFileUtils.loadImage("transport_play_2.png");
		this.transportPause = TGFileUtils.loadImage("transport_pause.png");				
		this.transportIconFirst1 = TGFileUtils.loadImage("transport_icon_first_1.png");
		this.transportIconFirst2 = TGFileUtils.loadImage("transport_icon_first_2.png");
		this.transportIconLast1 = TGFileUtils.loadImage("transport_icon_last_1.png");
		this.transportIconLast2 = TGFileUtils.loadImage("transport_icon_last_2.png");
		this.transportIconPrevious1 = TGFileUtils.loadImage("transport_icon_previous_1.png");
		this.transportIconPrevious2 = TGFileUtils.loadImage("transport_icon_previous_2.png");
		this.transportIconNext1 = TGFileUtils.loadImage("transport_icon_next_1.png");
		this.transportIconNext2 = TGFileUtils.loadImage("transport_icon_next_2.png");
		this.transportIconStop1 = TGFileUtils.loadImage("transport_icon_stop_1.png");
		this.transportIconStop2 = TGFileUtils.loadImage("transport_icon_stop_2.png");
		this.transportIconPlay1 = TGFileUtils.loadImage("transport_icon_play_1.png");
		this.transportIconPlay2 = TGFileUtils.loadImage("transport_icon_play_2.png");
		this.transportIconPause = TGFileUtils.loadImage("transport_icon_pause.png");
		this.transportMetronome = TGFileUtils.loadImage("transport_metronome.png");
		this.transportMode = TGFileUtils.loadImage("transport_mode.png");
		this.markerList = TGFileUtils.loadImage("marker_list.png");
		this.markerAdd = TGFileUtils.loadImage("marker_add.png");
		this.markerRemove = TGFileUtils.loadImage("marker_remove.png");
		this.markerFirst = TGFileUtils.loadImage("marker_first.png");
		this.markerLast = TGFileUtils.loadImage("marker_last.png");
		this.markerPrevious = TGFileUtils.loadImage("marker_previous.png");
		this.markerNext = TGFileUtils.loadImage("marker_next.png");					
		this.mixer = TGFileUtils.loadImage("mixer.png");			
		this.dynamicPPP = TGFileUtils.loadImage("dynamic_ppp.png");	
		this.dynamicPP = TGFileUtils.loadImage("dynamic_pp.png");		
		this.dynamicP = TGFileUtils.loadImage("dynamic_p.png");		
		this.dynamicMP =TGFileUtils.loadImage("dynamic_mp.png");		
		this.dynamicMF = TGFileUtils.loadImage("dynamic_mf.png");		
		this.dynamicF = TGFileUtils.loadImage("dynamic_f.png");		
		this.dynamicFF = TGFileUtils.loadImage("dynamic_ff.png");		
		this.dynamicFFF = TGFileUtils.loadImage("dynamic_fff.png");		
		this.effectDead = TGFileUtils.loadImage("effect_dead.png");
		this.effectGhost = TGFileUtils.loadImage("effect_ghost.png");
		this.effectAccentuated = TGFileUtils.loadImage("effect_accentuated.png");
		this.effectHeavyAccentuated = TGFileUtils.loadImage("effect_heavy_accentuated.png");
		this.effectHarmonic = TGFileUtils.loadImage("effect_harmonic.png");
		this.effectGrace = TGFileUtils.loadImage("effect_grace.png");
		this.effectBend = TGFileUtils.loadImage("effect_bend.png");
		this.effectTremoloBar = TGFileUtils.loadImage("effect_tremolo_bar.png");
		this.effectSlide = TGFileUtils.loadImage("effect_slide.png");
		this.effectHammer = TGFileUtils.loadImage("effect_hammer.png");
		this.effectVibrato = TGFileUtils.loadImage("effect_vibrato.png");
		this.effectTrill= TGFileUtils.loadImage("effect_trill.png");
		this.effectTremoloPicking = TGFileUtils.loadImage("effect_tremolo_picking.png");
		this.effectPalmMute= TGFileUtils.loadImage("effect_palm_mute.png");	
		this.effectStaccato = TGFileUtils.loadImage("effect_staccato.png");
		this.effectTapping = TGFileUtils.loadImage("effect_tapping.png");
		this.effectSlapping = TGFileUtils.loadImage("effect_slapping.png");
		this.effectPopping = TGFileUtils.loadImage("effect_popping.png");
		this.effectFadeIn = TGFileUtils.loadImage("effect_fade_in.png");					
		this.browserNew = TGFileUtils.loadImage("browser_new.png");
		this.browserFile = TGFileUtils.loadImage("browser_file.png");		
		this.browserFolder = TGFileUtils.loadImage("browser_folder.png");		
		this.browserRoot = TGFileUtils.loadImage("browser_root.png");		
		this.browserBack = TGFileUtils.loadImage("browser_back.png");		
		this.browserRefresh = TGFileUtils.loadImage("browser_refresh.png");
		this.settings = TGFileUtils.loadImage("settings.png");
	}
	
	public void disposeIcons(){
		for(int i = 0;i < this.durations.length;i++){
			this.durations[i].dispose();
		}
		this.fileNew.dispose();
		this.fileOpen.dispose();
		this.fileSave.dispose();
		this.fileSaveAs.dispose();
		this.filePrint.dispose();
		this.filePrintPreview.dispose();					
		this.editUndo.dispose();
		this.editRedo.dispose();
		this.editModeSelection.dispose();
		this.editModeEdition.dispose();		
		this.editModeEditionNotNatural.dispose();
		this.layoutPage.dispose();
		this.layoutLinear.dispose();
		this.layoutMultitrack.dispose();
		this.layoutScore.dispose();	
		this.layoutCompact.dispose();
		this.fretboard.dispose();	
		this.fretboardFirstFret.dispose();	
		this.fretboardFret.dispose();				
		this.transport.dispose();
		this.transportFirst1.dispose();
		this.transportFirst2.dispose();
		this.transportLast1.dispose();
		this.transportLast2.dispose();
		this.transportPrevious1.dispose();
		this.transportPrevious2.dispose();
		this.transportNext1.dispose();
		this.transportNext2.dispose();
		this.transportStop1.dispose();
		this.transportStop2.dispose();
		this.transportPlay1.dispose();
		this.transportPlay2.dispose();
		this.transportPause.dispose();					
		this.transportIconFirst1.dispose();			
		this.transportIconFirst2.dispose();			
		this.transportIconLast1.dispose();			
		this.transportIconLast2.dispose();			
		this.transportIconPrevious1.dispose();			
		this.transportIconPrevious2.dispose();			
		this.transportIconNext1.dispose();			
		this.transportIconNext2.dispose();			
		this.transportIconStop1.dispose();			
		this.transportIconStop2.dispose();			
		this.transportIconPlay1.dispose();			
		this.transportIconPlay2.dispose();
		this.transportIconPause.dispose();
		this.transportMetronome.dispose();
		this.transportMode.dispose();
		this.markerList.dispose();
		this.markerAdd.dispose();
		this.markerRemove.dispose();
		this.markerFirst.dispose();
		this.markerLast.dispose();
		this.markerPrevious.dispose();
		this.markerNext.dispose();				
		this.aboutDescription.dispose();	
		this.aboutLicense.dispose();	
		this.aboutAuthors.dispose();		
		this.appIcon.dispose();
		this.appSplash.dispose();		
		this.optionMain.dispose();
		this.optionStyle.dispose();
		this.optionSound.dispose();
		this.optionLanguage.dispose();
		this.optionToolbars.dispose();	
		this.optionSkin.dispose();
		this.compositionTimeSignature.dispose();
		this.compositionTempo.dispose();
		this.compositionRepeatOpen.dispose();
		this.compositionRepeatClose.dispose();		
		this.compositionRepeatAlternative.dispose();
		this.songProperties.dispose();		
		this.trackAdd.dispose();
		this.trackRemove.dispose();		
		this.paintableTempo.dispose();
		this.paintableGrace.dispose();
		this.durationDotted.dispose();
		this.durationDoubleDotted.dispose();
		this.durationTupleto.dispose();				
		this.chord.dispose();	
		this.noteTied.dispose();			
		this.mixer.dispose();				
		this.dynamicPPP.dispose();	
		this.dynamicPP.dispose();	
		this.dynamicP.dispose();	
		this.dynamicMP.dispose();		
		this.dynamicMF.dispose();	
		this.dynamicF.dispose();	
		this.dynamicFF .dispose();	
		this.dynamicFFF.dispose();					
		this.effectDead.dispose();	
		this.effectGhost.dispose();	
		this.effectAccentuated.dispose();	
		this.effectHeavyAccentuated.dispose();	
		this.effectHarmonic.dispose();	
		this.effectGrace.dispose();	
		this.effectBend.dispose();	
		this.effectTremoloBar.dispose();	
		this.effectSlide.dispose();	
		this.effectHammer.dispose();	
		this.effectVibrato.dispose();	
		this.effectTrill.dispose();	
		this.effectTremoloPicking.dispose();	
		this.effectPalmMute.dispose();		
		this.effectStaccato.dispose();	
		this.effectTapping.dispose();	
		this.effectSlapping.dispose();	
		this.effectPopping.dispose();	
		this.effectFadeIn.dispose();
		this.browserNew.dispose();
		this.browserFile.dispose();
		this.browserFolder.dispose();
		this.browserRoot.dispose();
		this.browserBack.dispose();
		this.browserRefresh.dispose();
		this.settings.dispose();
	}

	public boolean shouldReload(){
		return (!this.theme.equals(TuxGuitar.instance().getConfig().getStringConfigValue(TGConfigKeys.SKIN)));
	}
	
	public Image getDuration(int value){
		switch(value){
		case TGDuration.WHOLE:
			return this.durations[0];
		case TGDuration.HALF:
			return this.durations[1];			
		case TGDuration.QUARTER:
			return this.durations[2];
		case TGDuration.EIGHTH:
			return this.durations[3];
		case TGDuration.SIXTEENTH:
			return this.durations[4];
		case TGDuration.THIRTY_SECOND:
			return this.durations[5];
		case TGDuration.SIXTY_FOURTH:
			return this.durations[6];			
		}
		return null;
	}	

	public Image getAboutAuthors() {
		return this.aboutAuthors;
	}

	public Image getAboutDescription() {
		return this.aboutDescription;
	}

	public Image getAboutLicense() {
		return this.aboutLicense;
	}

	public Image getAppIcon() {
		return this.appIcon;
	}

	public Image getAppSplash() {
		return this.appSplash;
	}

	public Image getChord() {
		return this.chord;
	}

	public Image getCompositionRepeatClose() {
		return this.compositionRepeatClose;
	}

	public Image getCompositionRepeatAlternative() {
		return this.compositionRepeatAlternative;
	}
	
	public Image getCompositionRepeatOpen() {
		return this.compositionRepeatOpen;
	}

	public Image getCompositionTempo() {
		return this.compositionTempo;
	}

	public Image getCompositionTimeSignature() {
		return this.compositionTimeSignature;
	}

	public Image getDurationDotted() {
		return this.durationDotted;
	}

	public Image getDurationDoubleDotted() {
		return this.durationDoubleDotted;
	}

	public Image getDurationTupleto() {
		return this.durationTupleto;
	}

	public Image getDynamicF() {
		return this.dynamicF;
	}

	public Image getDynamicFF() {
		return this.dynamicFF;
	}

	public Image getDynamicFFF() {
		return this.dynamicFFF;
	}

	public Image getDynamicMF() {
		return this.dynamicMF;
	}

	public Image getDynamicMP() {
		return this.dynamicMP;
	}

	public Image getDynamicP() {
		return this.dynamicP;
	}

	public Image getDynamicPP() {
		return this.dynamicPP;
	}

	public Image getDynamicPPP() {
		return this.dynamicPPP;
	}

	public Image getEditModeEdition() {
		return this.editModeEdition;
	}

	public Image getEditModeEditionNotNatural() {
		return this.editModeEditionNotNatural;
	}

	public Image getEditModeSelection() {
		return this.editModeSelection;
	}

	public Image getEditRedo() {
		return this.editRedo;
	}

	public Image getEditUndo() {
		return this.editUndo;
	}

	public Image getEffectAccentuated() {
		return this.effectAccentuated;
	}

	public Image getEffectBend() {
		return this.effectBend;
	}

	public Image getEffectDead() {
		return this.effectDead;
	}

	public Image getEffectFadeIn() {
		return this.effectFadeIn;
	}

	public Image getEffectGhost() {
		return this.effectGhost;
	}

	public Image getEffectGrace() {
		return this.effectGrace;
	}

	public Image getEffectHammer() {
		return this.effectHammer;
	}

	public Image getEffectHarmonic() {
		return this.effectHarmonic;
	}

	public Image getEffectHeavyAccentuated() {
		return this.effectHeavyAccentuated;
	}

	public Image getEffectPalmMute() {
		return this.effectPalmMute;
	}

	public Image getEffectPopping() {
		return this.effectPopping;
	}

	public Image getEffectSlapping() {
		return this.effectSlapping;
	}

	public Image getEffectSlide() {
		return this.effectSlide;
	}

	public Image getEffectStaccato() {
		return this.effectStaccato;
	}

	public Image getEffectTapping() {
		return this.effectTapping;
	}

	public Image getEffectTremoloBar() {
		return this.effectTremoloBar;
	}

	public Image getEffectTremoloPicking() {
		return this.effectTremoloPicking;
	}

	public Image getEffectTrill() {
		return this.effectTrill;
	}

	public Image getEffectVibrato() {
		return this.effectVibrato;
	}

	public Image getFileNew() {
		return this.fileNew;
	}

	public Image getFileOpen() {
		return this.fileOpen;
	}

	public Image getFilePrint() {
		return this.filePrint;
	}

	public Image getFilePrintPreview() {
		return this.filePrintPreview;
	}

	public Image getFileSave() {
		return this.fileSave;
	}

	public Image getFileSaveAs() {
		return this.fileSaveAs;
	}

	public Image getFretboard() {
		return this.fretboard;
	}

	public Image getFretboardFirstFret() {
		return this.fretboardFirstFret;
	}

	public Image getFretboardFret() {
		return this.fretboardFret;
	}

	public Image getLayoutLinear() {
		return this.layoutLinear;
	}

	public Image getLayoutMultitrack() {
		return this.layoutMultitrack;
	}

	public Image getLayoutPage() {
		return this.layoutPage;
	}

	public Image getLayoutScore() {
		return this.layoutScore;
	}

	public Image getLayoutCompact() {
		return this.layoutCompact;
	}
	
	public Image getMarkerAdd() {
		return this.markerAdd;
	}

	public Image getMarkerFirst() {
		return this.markerFirst;
	}

	public Image getMarkerLast() {
		return this.markerLast;
	}

	public Image getMarkerList() {
		return this.markerList;
	}

	public Image getMarkerNext() {
		return this.markerNext;
	}

	public Image getMarkerPrevious() {
		return this.markerPrevious;
	}

	public Image getMarkerRemove() {
		return this.markerRemove;
	}

	public Image getMixer() {
		return this.mixer;
	}

	public Image getNoteTied() {
		return this.noteTied;
	}

	public Image getOptionLanguage() {
		return this.optionLanguage;
	}

	public Image getOptionMain() {
		return this.optionMain;
	}

	public Image getOptionSound() {
		return this.optionSound;
	}

	public Image getOptionStyle() {
		return this.optionStyle;
	}

	public Image getOptionToolbars() {
		return this.optionToolbars;
	}

	public Image getOptionSkin() {
		return this.optionSkin;
	}

	public Image getPaintableGrace() {
		return this.paintableGrace;
	}

	public Image getPaintableTempo() {
		return this.paintableTempo;
	}

	public Image getSongProperties() {
		return this.songProperties;
	}

	public Image getTrackAdd() {
		return this.trackAdd;
	}

	public Image getTrackRemove() {
		return this.trackRemove;
	}

	public Image getTransport() {
		return this.transport;
	}

	public Image getTransportFirst1() {
		return this.transportFirst1;
	}

	public Image getTransportFirst2() {
		return this.transportFirst2;
	}

	public Image getTransportIconFirst1() {
		return this.transportIconFirst1;
	}

	public Image getTransportIconFirst2() {
		return this.transportIconFirst2;
	}

	public Image getTransportIconLast1() {
		return this.transportIconLast1;
	}

	public Image getTransportIconLast2() {
		return this.transportIconLast2;
	}

	public Image getTransportIconNext1() {
		return this.transportIconNext1;
	}

	public Image getTransportIconNext2() {
		return this.transportIconNext2;
	}

	public Image getTransportIconPause() {
		return this.transportIconPause;
	}

	public Image getTransportIconPlay1() {
		return this.transportIconPlay1;
	}

	public Image getTransportIconPlay2() {
		return this.transportIconPlay2;
	}

	public Image getTransportIconPrevious1() {
		return this.transportIconPrevious1;
	}

	public Image getTransportIconPrevious2() {
		return this.transportIconPrevious2;
	}

	public Image getTransportIconStop1() {
		return this.transportIconStop1;
	}

	public Image getTransportIconStop2() {
		return this.transportIconStop2;
	}

	public Image getTransportLast1() {
		return this.transportLast1;
	}

	public Image getTransportLast2() {
		return this.transportLast2;
	}

	public Image getTransportNext1() {
		return this.transportNext1;
	}

	public Image getTransportNext2() {
		return this.transportNext2;
	}

	public Image getTransportPause() {
		return this.transportPause;
	}

	public Image getTransportPlay1() {
		return this.transportPlay1;
	}

	public Image getTransportPlay2() {
		return this.transportPlay2;
	}

	public Image getTransportPrevious1() {
		return this.transportPrevious1;
	}

	public Image getTransportPrevious2() {
		return this.transportPrevious2;
	}

	public Image getTransportStop1() {
		return this.transportStop1;
	}

	public Image getTransportStop2() {
		return this.transportStop2;
	}

	public Image getTransportMetronome() {
		return this.transportMetronome;
	}

	public Image getTransportMode() {
		return this.transportMode;
	}
	
	public Image getBrowserBack() {
		return this.browserBack;
	}

	public Image getBrowserFile() {
		return this.browserFile;
	}

	public Image getBrowserFolder() {
		return this.browserFolder;
	}

	public Image getBrowserRefresh() {
		return this.browserRefresh;
	}

	public Image getBrowserRoot() {
		return this.browserRoot;
	}
		
	public Image getBrowserNew() {
		return this.browserNew;
	}

	public Image getSettings() {
		return this.settings;
	}	
	
}
